/* $Id: robx.h,v 1.3 2005/04/04 11:16:22 relson Exp $ */

/*****************************************************************************

NAME:
   robx.h -- prototypes and definitions for robx.c

******************************************************************************/

#ifndef	HAVE_ROBX_H
#define	HAVE_ROBX_H

double compute_robinson_x(void);

#endif	/* HAVE_ROBX_H */
